@@ -294,7 +294,7 @@ class Backend(object):
 
         if not self._can_extents:
             if context == "zero":
-                yield image.ZeroExtent(0, self.size(), False)
+                yield image.ZeroExtent(0, self.size(), False, False)
                 return
             else:
                 raise errors.UnsupportedOperation(
@@ -512,7 +512,7 @@ class Backend(object):
 
         cls = image.ZeroExtent if context == "zero" else image.DirtyExtent
         for ext in extents:
-            yield cls(ext["start"], ext["length"], ext[context])
+            yield cls.from_dict(ext)
 
     def _emulate_head(self):
         """
