@@ -80,8 +80,28 @@ class Server(socketserver.ThreadingMixIn,
     # profiling.
     clock_class = stats.NullClock
 
-    def server_bind(self):
-        """Override server_bind to create socket with correct family."""
+    def __init__(self, server_address, RequestHandlerClass, prefer_ipv4=False):
+        super().__init__(
+            server_address, RequestHandlerClass, bind_and_activate=False)
+
+        # Close old socket created in parent constructor.
+        if self.socket:
+            self.socket.close()
+
+        try:
+            self.create_socket(prefer_ipv4)
+            self.server_bind()
+            self.server_activate()
+        except BaseException:
+            self.server_close()
+            raise
+
+    def create_socket(self, prefer_ipv4=False):
+        """
+        Create socket with correct socket family.
+        If prefer_ipv4 is set, and both ipv4 and ipv6 addresses are
+        available, pick the first ipv4 address.
+        """
         host, port = self.server_address
 
         # In the past we use "" as a special address to bind to all interfaces.
@@ -93,20 +113,28 @@ class Server(socketserver.ThreadingMixIn,
             host = "0"
 
         addresses = socket.getaddrinfo(host, port, type=self.socket_type)
+
+        # If IPv4 is preferred, sort addresses according to address family, so
+        # that IPv4 addresses are before IPv6 addresses. Addresses is a list of
+        # tuples, address family being the first item in the tuple.
+        log.debug("Prefer IPv4: %s", prefer_ipv4)
+        if prefer_ipv4:
+            addresses.sort(key=lambda x: x[0] != socket.AF_INET)
+
         log.debug("Available network interfaces: %s", addresses)
         self.address_family = addresses[0][0]
 
-        # Close old socket created in constructor first.
-        if self.socket:
-            self.socket.close()
-
         # Create new socket with correct address family.
-        log.info(
+        log.debug(
             "Creating server socket with family=%s and type=%s",
             self.address_family,
             self.socket_type)
         self.socket = socket.socket(self.address_family, self.socket_type)
 
+    def server_bind(self):
+        """
+        Override server_bind to make server_address uniform.
+        """
         super().server_bind()
 
         # TCPServer.server_bind() overwrites server_address with
